UserProfile class

Constructors

UserProfile({String? sub, String? name, String? locale, String? email, String? preferredUsername, String? givenName, String? familyName, String? zoneInfo, int? updatedAt, bool? emailVerified})
UserProfile.empty()
factory
UserProfile.fromMap(Map<String, dynamic> data)
factory

Properties

email String?
getter/setter pair
emailVerified bool?
getter/setter pair
familyName String?
getter/setter pair
givenName String?
getter/setter pair
hasData bool
no setter
hashCode int
The hash code for this object.
no setterinherited
locale String?
getter/setter pair
name String?
getter/setter pair
preferredUsername String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sub String?
getter/setter pair
updatedAt int?
getter/setter pair
zoneInfo String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited