MethodChannelOktaFlutter class

An implementation of OktaFlutterPlatform that uses method channels.

Inheritance

Constructors

MethodChannelOktaFlutter()

Properties

hashCode int
The hash code for this object.
no setterinherited
methodChannel MethodChannel
The method channel used to interact with the native platform.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createOIDCConfig(OktaConfig config) Future<bool?>
override
getUserProfile() Future<UserProfile?>
override
isAuthenticated() Future<bool>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
refreshToken() Future<OktaResult>
override
signIn() Future<OktaResult>
override
signOut() Future<OktaResult>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited