OktaFlutterPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • OktaFlutterPlatform
Implementers

Constructors

OktaFlutterPlatform()
Constructs a OktaFlutterPlatform.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createOIDCConfig(OktaConfig config) Future<bool?>
getUserProfile() Future<UserProfile?>
isAuthenticated() Future<bool>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
refreshToken() Future<OktaResult>
signIn() Future<OktaResult>
signOut() Future<OktaResult>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance OktaFlutterPlatform
The default instance of OktaFlutterPlatform to use.
getter/setter pair